@@ -23,7 +23,7 @@ class DockerVolume(TypedDict):
 
 
 class SecretEnvSource(TypedDict):
-    secret: str  # full name of k8s secret resource
+    secret_name: str  # full name of k8s secret resource
     key: str
 
 
@@ -44,6 +44,7 @@ class KubernetesTaskState(AutoEnum):
     TASK_FINISHED = auto()
     TASK_FAILED = auto()
     TASK_UNKNOWN = auto()
+    TASK_LOST = auto()
 
 
 class KubernetesTaskMetadata(PRecord):
